aboutsummaryrefslogtreecommitdiff
path: root/main.go
diff options
context:
space:
mode:
Diffstat (limited to 'main.go')
-rw-r--r--main.go6
1 files changed, 3 insertions, 3 deletions
diff --git a/main.go b/main.go
index 0c8dd32..5275c26 100644
--- a/main.go
+++ b/main.go
@@ -702,8 +702,8 @@ func handleAPIOrphans(w http.ResponseWriter, r *http.Request) {
// - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
-// cmdRun runs a web UI against GD on ADDRESS.
-func cmdRun(args []string) error {
+// cmdWeb runs a web UI against GD on ADDRESS.
+func cmdWeb(args []string) error {
if len(args) != 2 {
return errors.New("usage: GD ADDRESS")
}
@@ -2082,7 +2082,7 @@ var commands = map[string]struct {
handler func(args []string) error
}{
"init": {cmdInit},
- "run": {cmdRun},
+ "web": {cmdWeb},
"import": {cmdImport},
"tag": {cmdTag},
"sync": {cmdSync},